#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsyslog
version:              5.0.2
visibility:           public
id:                   hsyslog-5.0.2-Ci0LX7In2Dj5c9BkmZZ3c0
key:                  hsyslog-5.0.2-Ci0LX7In2Dj5c9BkmZZ3c0
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2017 by Peter Simons
maintainer:           Peter Simons <simons@cryp.to>
author:               Peter Simons, John Lato, Jonathan Childress
homepage:             http://github.com/peti/hsyslog
synopsis:             FFI interface to syslog(3) from POSIX.1-2001
description:
    A Haskell interface to @syslog(3)@ as specified in
    <http://pubs.opengroup.org/onlinepubs/9699919799/functions/syslog.html POSIX.1-2008>.
    The entire public API lives in "System.Posix.Syslog". There is a set of exposed
    modules available underneath that one, which contain various implementation details
    that may be useful to other developers who want to implement syslog-related
    functionality. /Users/ of @syslog@, however, do not need them.

    An example program that demonstrates how to use this library is available in the
    <https://github.com/peti/hsyslog/blob/master/example/Main.hs examples> directory of
    this package.

category:             Foreign
abi:                  d32eb629ed2143ca9138932a46f3fdf6
exposed:              True
exposed-modules:
    System.Posix.Syslog System.Posix.Syslog.Facility
    System.Posix.Syslog.Functions System.Posix.Syslog.LogMask
    System.Posix.Syslog.Options System.Posix.Syslog.Priority

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hsyslog-5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hsyslog-5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hsyslog-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyslog
hs-libraries:         HShsyslog-5.0.2-Ci0LX7In2Dj5c9BkmZZ3c0
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-hsyslog/html/hsyslog.haddock
haddock-html:         /usr/share/doc/haskell-hsyslog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

